@@ -18,8 +18,9 @@ OC.L10N.register(
     "New event" : "حدث جديد",
     "Share Calendar" : "مشاركة المفكرة",
     "Shared" : "مشارك",
+    "Email sent." : "تم إرسال الرسالة الإلكترونية.",
     "group" : "مجموعة",
-    "Details" : "تفاصيل",
+    "Details" : "التفاصيل",
     "Attendees" : "المشاركون",
     "Reminders" : "تذكيرات",
     "Repeating" : "التكرار",
@@ -28,7 +29,7 @@ OC.L10N.register(
     "When shared hide this event" : "إخفاء الحدث عند مشاركته",
     "Confirmed" : "مؤكَّد",
     "Tentative" : "مبدئي",
-    "Cancelled" : "ملغي",
+    "Cancelled" : "ملغى",
     "Please add a title." : "يرجى إضافة عنوان.",
     "Global" : "عالمي",
     "None" : "لا شيء",
@@ -48,13 +49,13 @@ OC.L10N.register(
     "2 hours before" : "قبل الحدث بـ  2 ساعتين",
     "Custom" : "مخصّص",
     "Audio" : "صوت",
-    "Email" : "بريد إلكتروني",
+    "Email" : "البريد الإلكتروني",
     "Pop-up" : "نافذة منبثقة",
     "sec" : "ثانية",
     "min" : "دقيقة",
     "hours" : "ساعات",
     "days" : "أيام",
-    "week" : "إسبوع",
+    "week" : "أسبوع",
     "before" : "قبل",
     "start" : "بداية",
     "end" : "نهاية",
@@ -90,14 +91,14 @@ OC.L10N.register(
     "More" : "المزيد",
     "Edit" : "تعديل",
     "Link" : "الرابط",
-    "Download" : "تحميل",
+    "Download" : "تنزيل",
     "Share with users or groups" : "شارِك مع مستخدمين أو مجموعات",
     "can edit" : "يمكن التحرير",
     "Share link" : "رابط المشاركة",
-    "Public access" : "العنوان العمومي",
+    "Public access" : "النفاذ إليه مُصرّح للعامة",
     "Send" : "إرسال",
     "New Calendar" : "مفكرة جديدة",
-    "Name" : "الاسم",
+    "Name" : "التسمية",
     "New Subscription" : "اشتراك جديد",
     "Go back" : "العودة",
     "Go forward" : "المواصلة",
@@ -110,9 +111,9 @@ OC.L10N.register(
     "Absolute" : "مستقل",
     "Repeat" : "التكرار",
     "times every" : "مرة كل",
-    "Add" : "اضف",
+    "Add" : "إضافة",
     "Please add your email address in the personal settings in order to add attendees." : "فضلاً آضف عنوان بريدك الإلكتروني في الإعدادات الشخصية للتمكن من إضافة الحاضرين.",
-    "from" : "من",
+    "from" : "مِن",
     "to" : "إلى",
     "This event's repeating rule is not supported yet." : "قاعدة تكرار هذا الحدث غير مدعومة حتى الآن.",
     "Support for advanced rules will be added with subsequent updates." : "دعم القواعد المتقدمة ستتم إضافته في التحديثات التالية.",
@@ -132,7 +133,6 @@ OC.L10N.register(
     "Import calendar" : "استيراد التقويم",
     "No Calendars selected for import" : "لم تختر تقويمات للاستيراد",
     "Show week numbers" : "إظهار رقم الأسابيع",
-    "Primary CalDAV address" : "الرئيسية CalDAV عناوين",
-    "iOS/OS X CalDAV address" : "لأنظمة التشغيل الماك/الآيفون CalDAV عناوين"
+    "Primary CalDAV address" : "الرئيسية CalDAV عناوين"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
