@@ -51,6 +51,7 @@ OC.L10N.register(
     "Every year" : "Всяка година",
     "never" : "никога",
     "after" : "переди",
+    "Automatic ({timezone})" : "Автоматично ({timezone})",
     "How about getting started by importing some calendars?" : "Какво ще кажете като започнете с внасяне на календари?",
     "At time of event" : "По време на събитието",
     "5 minutes before" : "5 минути преди",
@@ -162,7 +163,6 @@ OC.L10N.register(
     "Skip simple event editor" : "Пропусни опростения редактор за събития",
     "Show week numbers" : "Показвай номерата на седмиците",
     "Primary CalDAV address" : "Основен CalDAV адрес",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV адрес",
     "Subscribe" : "Абонирай ме"
 },
 "nplurals=2; plural=(n != 1);");
