@@ -8,7 +8,7 @@ OC.L10N.register(
     "Open »%s«" : "Åpne \"%s\"",
     "Cheers!" : "Ha det!",
     "Recipient" : "Mottaker",
-    "Too many redirects. Aborting ..." : "For mange videresendinger. Avbryter…",
+    "Too many redirects. Aborting ..." : "For mange videresendinger. Avbryter …",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ekstern tjener nektet tilgang til kalenderen (HTTP {%s} error)",
     "Error connecting to remote server" : "Feil ved opprettelsen av forbindelse til tjeneren",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Feil ved forespørsel om ressurser på ekstern tjener. Dette er trolig relatert til sertifikatavvik.",
@@ -55,6 +55,7 @@ OC.L10N.register(
     "Every year" : "Hvert år",
     "never" : "aldri",
     "after" : "etter",
+    "Automatic ({timezone})" : "Automatisk ({timezone})",
     "How about getting started by importing some calendars?" : "Hva med å starte import av noen kalendere?",
     "At time of event" : "Ved tiden for hendelsen",
     "5 minutes before" : "5 minutter før",
@@ -90,17 +91,17 @@ OC.L10N.register(
     "{type} {time} before the event starts" : "{type} {time} før hendelsen starter",
     "Audio alarm {time} before the event ends" : "Lydalarm {time} før hendelsen slutter",
     "Pop-up {time} before the event ends" : "Popup {time} før hendelsen slutter",
-    "Email {time} before the event ends" : "Epost {time} før hendelsen slutter",
+    "Email {time} before the event ends" : "E-post {time} før hendelsen slutter",
     "None {time} before the event ends" : "Ingen {time} før hendelsen slutter",
     "{type} {time} before the event ends" : "{type} {time} før hendelsen slutter",
     "Audio alarm {time} after the event starts" : "Lydalarm {time} etter at hendelsen har startet",
     "Pop-up {time} after the event starts" : "Popup {time} etter at hendelsen har startet",
-    "Email {time} after the event starts" : "Epost {time} etter at hendelsen har startet",
+    "Email {time} after the event starts" : "E-post {time} etter at hendelsen har startet",
     "None {time} after the event starts" : "Ingen {time} etter at hendelsen har startet",
     "{type} {time} after the event starts" : "{type} {time} etter hendelsen starter",
     "Audio alarm {time} after the event ends" : "Lydalarm {time} etter at hendelsen har sluttet",
     "Pop-up {time} after the event ends" : "Popup {time} etter at hendelsen har sluttet",
-    "Email {time} after the event ends" : "Epost {time} etter at hendelsen har sluttet",
+    "Email {time} after the event ends" : "E-post {time} etter at hendelsen har sluttet",
     "None {time} after the event ends" : "Ingen {time} etter at hendelsen har sluttet",
     "{type} {time} after the event ends" : "{type} {time} etter hendelsen slutter",
     "Audio alarm at the event's start" : "Lydalarm når hendelsen starter",
@@ -190,6 +191,7 @@ OC.L10N.register(
     "The file contains objects incompatible with the selected calendar" : "Filen inneholder objekter som ikke passer sammen med den valgte kalenderen",
     "New calendar" : "Ny kalender",
     "File is empty" : "Filen er tom",
+    "File could not be parsed" : "Filen kunne ikke behandles",
     "Import scheduled" : "Importer planlagte",
     "%s shared the calendar <strong>%s</strong> with you" : "%s delte kalenderen <strong>%s</strong> med deg",
     "Embed" : "Innebygg",
@@ -200,8 +202,9 @@ OC.L10N.register(
     "No Calendars selected for import" : "Ingen kalendre valgt for import",
     "Skip simple event editor" : "Hopp over enkelt hendelsesredigering",
     "Show week numbers" : "Vis ukenumre",
+    "Timezone" : "Tidssone",
     "Primary CalDAV address" : "Primær CalDAV-adresse",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse",
+    "iOS/macOS CalDAV address" : "iOS/macOS CalDAV-adresse",
     "Subscribe" : "Abonner"
 },
 "nplurals=2; plural=(n != 1);");
